summaryrefslogtreecommitdiff
path: root/src/mesa/shader/program_parse.tab.c
diff options
context:
space:
mode:
authorBrian Paul <brianp@vmware.com>2010-02-19 12:56:49 -0700
committerBrian Paul <brianp@vmware.com>2010-02-19 12:56:49 -0700
commit78a0c353d0f87c85feaa6dcb3042fc25d424f21b (patch)
treeea638e071a08127708883560bdb96b8c0547d854 /src/mesa/shader/program_parse.tab.c
parent8de5a292f70dba854a4bf06a2210bc38381e6bcf (diff)
mesa: restore _mesa_snprintf() - it's needed for Windows
This reverts part of commit 298be2b028263b2c343a707662c6fbfa18293cb2
Diffstat (limited to 'src/mesa/shader/program_parse.tab.c')
-rw-r--r--src/mesa/shader/program_parse.tab.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mesa/shader/program_parse.tab.c b/src/mesa/shader/program_parse.tab.c
index 3f26f9f84a..52f6084358 100644
--- a/src/mesa/shader/program_parse.tab.c
+++ b/src/mesa/shader/program_parse.tab.c
@@ -2984,7 +2984,7 @@ yyreduce:
{
if (((yyvsp[(1) - (1)].integer) < 0) || ((yyvsp[(1) - (1)].integer) > 63)) {
char s[100];
- snprintf(s, sizeof(s),
+ _mesa_snprintf(s, sizeof(s),
"relative address offset too large (%d)", (yyvsp[(1) - (1)].integer));
yyerror(& (yylsp[(1) - (1)]), state, s);
YYERROR;
@@ -3001,7 +3001,7 @@ yyreduce:
{
if (((yyvsp[(1) - (1)].integer) < 0) || ((yyvsp[(1) - (1)].integer) > 64)) {
char s[100];
- snprintf(s, sizeof(s),
+ _mesa_snprintf(s, sizeof(s),
"relative address offset too large (%d)", (yyvsp[(1) - (1)].integer));
yyerror(& (yylsp[(1) - (1)]), state, s);
YYERROR;
@@ -4915,7 +4915,7 @@ yyreduce:
if (exist != NULL) {
char m[1000];
- snprintf(m, sizeof(m), "redeclared identifier: %s", (yyvsp[(2) - (4)].string));
+ _mesa_snprintf(m, sizeof(m), "redeclared identifier: %s", (yyvsp[(2) - (4)].string));
free((yyvsp[(2) - (4)].string));
yyerror(& (yylsp[(2) - (4)]), state, m);
YYERROR;
@@ -5559,18 +5559,18 @@ make_error_string(const char *fmt, ...)
va_start(args, fmt);
/* Call vsnprintf once to determine how large the final string is. Call it
* again to do the actual formatting. from the vsnprintf manual page:
*
* Upon successful return, these functions return the number of
* characters printed (not including the trailing '\0' used to end
* output to strings).
*/
- length = 1 + vsnprintf(NULL, 0, fmt, args);
+ length = 1 + v_mesa_snprintf(NULL, 0, fmt, args);
str = malloc(length);
if (str) {
- vsnprintf(str, length, fmt, args);
+ v_mesa_snprintf(str, length, fmt, args);
}
va_end(args);
@@ -5559,18 +5559,18 @@ make_error_string(const char *fmt, ...)
va_start(args, fmt);
- /* Call vsnprintf once to determine how large the final string is. Call it
- * again to do the actual formatting. from the vsnprintf manual page:
+ /* Call v_mesa_snprintf once to determine how large the final string is. Call it
+ * again to do the actual formatting. from the v_mesa_snprintf manual page:
*
* Upon successful return, these functions return the number of